@@ -668,6 +668,7 @@ static void stop () {
     }
     if (gst_elm_play) {
         GstState current_state;
+        GstElement *element;
         gst_element_get_state (gst_elm_play, &current_state, NULL, 0);
         if (current_state > GST_STATE_READY) {
             gst_element_set_state (gst_elm_play, GST_STATE_READY);
@@ -675,6 +676,16 @@ static void stop () {
         }
         gst_element_set_state (gst_elm_play, GST_STATE_NULL);
         gst_element_get_state (gst_elm_play, NULL, NULL, -1);
+        g_object_get (gst_elm_play, "video-sink", &element, NULL);
+        if (element) {
+            gst_element_set_state (element, GST_STATE_NULL);
+            gst_object_unref (element);
+        }
+        g_object_get (gst_elm_play, "audio-sink", &element, NULL);
+        if (element) {
+            gst_element_set_state (element, GST_STATE_NULL);
+            gst_object_unref (element);
+        }
     }
     g_idle_add (cb_finished, NULL);
 }
@@ -845,9 +856,7 @@ static gboolean cb_finished (gpointer data) {
         if (gst_bus_async)
             g_signal_handler_disconnect (gst_bus, gst_bus_async);
         gst_object_unref (gst_bus);
-        /*if (StatePlaying != transition_state)
-            / * work around crash in libpulse.so.0(pa_context_disconnect * /
-            gst_object_unref (GST_OBJECT (gst_elm_play));*/
+        gst_object_unref (GST_OBJECT (gst_elm_play));
         gst_bus = 0L;
         gst_elm_play = 0L;
         color_balance = 0L;
@@ -932,7 +941,7 @@ static void sig_abort(int i) {
     if (!n)
         return;
     backtrace_symbols_fd (trace, n, 2);
-    exit(0);
+    _exit(0);
 }
 
 int main (int argc, char **argv) {
