@@ -89,15 +89,11 @@ void app_insert_location (Application *app, const char *loc) {
         const gchar *val;
         gtk_tree_model_get_value (model, &it, 0, &value);
         val = g_value_get_string (&value);
-        if (!val || !val[0]) {
+        if (!val || !val[0] || !strcmp (val, loc) || count > 6) {
             b = gtk_list_store_remove (GTK_LIST_STORE (model), &it);
         } else {
-            if (!strcmp (val, loc) || count > 6) {
-                b = gtk_list_store_remove (GTK_LIST_STORE (model), &it);
-            } else {
-                b = gtk_tree_model_iter_next (model, &it);
-                count++;
-            }
+            b = gtk_tree_model_iter_next (model, &it);
+            count++;
         }
         g_value_unset (&value);
     }
@@ -192,6 +188,7 @@ void app_normal_screen (Application *app) {
         gtk_window_unfullscreen (app->window);
         gtk_widget_show (app->playlist_area);
         gtk_widget_hide (app->video_stop);
+        gtk_widget_hide (app->aspects_toggle);
         gtk_widget_hide (app->title_area);
         gtk_widget_hide (GTK_WIDGET (app->tb_favorites));
         gtk_fixed_move (GTK_FIXED(app->window_area), app->toolbar_area, 0, 354);
@@ -221,6 +218,7 @@ void app_store_save_directory (Application *app, gchar *path) {
 static gboolean _controlsTimeout (Application *app)
 {
     gtk_widget_hide (app->video_stop);
+    gtk_widget_hide (app->aspects_toggle);
     if (app->fullscreen)
         gtk_widget_hide (app->toolbar_area);
     gtk_widget_hide (app->title_area);
@@ -235,8 +233,10 @@ void app_show_controls (Application *app)
             g_source_remove (app->controls_timer);
         app->controls_timer = g_timeout_add (2000, (GSourceFunc) _controlsTimeout, app);
         gtk_widget_show_all (app->video_stop);
-        if (app->show_playlist)
+        if (app->show_playlist) {
             gtk_widget_show (app->toolbar_area);
+            gtk_widget_show_all (app->aspects_toggle);
+        }
     }
 }
 
@@ -466,6 +466,7 @@ static void create_menu (Application * app) {
     GtkWidget *item_playlist_generators;
     GtkWidget *item_players;
     GtkWidget *item_downloads;
+    GtkWidget *item_clear_history;
 
     main_menu = HILDON_APP_MENU (hildon_app_menu_new ());
 
@@ -479,6 +480,7 @@ static void create_menu (Application * app) {
     app->menu_item_playlist_cut = makeMenuButton("Cut");
     item_players = makeMenuButton ("Select Player");
     item_downloads = makeMenuButton ("Download Page");
+    item_clear_history = makeMenuButton ("Clear History");
 
     hildon_app_menu_append (main_menu, GTK_BUTTON (item_new));
     hildon_app_menu_append (main_menu, GTK_BUTTON (item_open));
@@ -490,6 +492,7 @@ static void create_menu (Application * app) {
     hildon_app_menu_append (main_menu, GTK_BUTTON (app->menu_item_playlist_paste));
     hildon_app_menu_append (main_menu, GTK_BUTTON (app->menu_item_playlist_paste_in_group));
     hildon_app_menu_append (main_menu, GTK_BUTTON (app->menu_item_playlist_cut));
+    hildon_app_menu_append (main_menu, GTK_BUTTON (item_clear_history));
 
     /* Attach the callback functions to the activate signal */
     g_signal_connect_after (G_OBJECT (item_new), "clicked",
@@ -512,6 +515,8 @@ static void create_menu (Application * app) {
         GTK_SIGNAL_FUNC (playerMenuActivate), app);
     g_signal_connect_after (G_OBJECT (item_downloads), "clicked",
         GTK_SIGNAL_FUNC (showDownloadPage), app);
+    g_signal_connect_after (G_OBJECT (item_clear_history), "clicked",
+        GTK_SIGNAL_FUNC (clearHistory), app);
 
     g_signal_connect (G_OBJECT (main_menu), "map-event",
         GTK_SIGNAL_FUNC (cb_playlistMenuActivate), app);
@@ -593,6 +598,7 @@ int main (int argc, char* argv[]) {
     PangoFontDescription *pfd;
     Application *app;
     GtkWidget *video_stop;
+    GtkWidget *aspects_toggle;
     GtkWidget *info_box;
     GtkWidget *info_align;
 
@@ -643,6 +649,7 @@ int main (int argc, char* argv[]) {
     app->window_area = gtk_fixed_new ();
     app->view_area = gtk_fixed_new ();
     app->video_stop = gtk_event_box_new ();
+    app->aspects_toggle = gtk_event_box_new ();
     app->title_area = gtk_event_box_new ();
     app->playlist_area = hildon_pannable_area_new ();
     app->toolbar_area = gtk_event_box_new ();
@@ -651,6 +658,7 @@ int main (int argc, char* argv[]) {
     info_align = gtk_alignment_new (0, 0, 1, 1);
 
     gtk_widget_set_size_request (app->video_stop, 70, 70);
+    gtk_widget_set_size_request (app->aspects_toggle, 70, 70);
     gtk_widget_set_size_request (app->title_area, 600, 70);
     gtk_widget_set_size_request (app->playlist_area, 800, 354);
     gtk_widget_set_size_request (app->toolbar_area, 800, 70);
@@ -669,9 +677,14 @@ int main (int argc, char* argv[]) {
 
     video_stop = GTK_WIDGET (gtk_tool_button_new (gtk_image_new_from_icon_name(
                     "general_close", HILDON_ICON_SIZE_TOOLBAR), NULL));
+    aspects_toggle = GTK_WIDGET(gtk_tool_button_new(gtk_image_new_from_icon_name(
+                    "camera_video_resolution_wide_screen",
+                    HILDON_ICON_SIZE_TOOLBAR), NULL));
 
     g_signal_connect (G_OBJECT (video_stop), "clicked",
             G_CALLBACK (cb_playlist_stop), app->control);
+    g_signal_connect (G_OBJECT (aspects_toggle), "clicked",
+            G_CALLBACK (cb_aspects_toggle), app->control);
     gtk_widget_add_events (app->view_area,
             GDK_EXPOSURE_MASK | GDK_VISIBILITY_NOTIFY_MASK |
             GDK_BUTTON_PRESS_MASK | GDK_KEY_PRESS_MASK |
@@ -724,9 +737,11 @@ int main (int argc, char* argv[]) {
     g_object_ref (app->info_viewport);
     g_object_ref (app->html_viewport);
     gtk_container_add (GTK_CONTAINER (app->video_stop), video_stop);
+    gtk_container_add (GTK_CONTAINER (app->aspects_toggle), aspects_toggle);
 
     gtk_fixed_put (GTK_FIXED (app->window_area), app->view_area, 0, 0);
     gtk_fixed_put (GTK_FIXED (app->window_area), app->video_stop, 730, 0);
+    gtk_fixed_put (GTK_FIXED (app->window_area), app->aspects_toggle, 730, 205);
     gtk_fixed_put (GTK_FIXED (app->window_area), app->title_area, 100, 0);
     gtk_fixed_put (GTK_FIXED (app->window_area), app->playlist_area, 0, 0);
     gtk_fixed_put (GTK_FIXED (app->window_area), app->toolbar_area, 0, 354);
