@@ -36,7 +36,8 @@
 #define GCONF_KEY_MIME GCONF_KEY_PREFIX"/mimetypes/"
 #define GCONF_KEY_LISTS GCONF_KEY_PREFIX"/lists"
 #define GCONF_KEY_LISTS_VIEW GCONF_KEY_PREFIX"/lists_view"
-#define GCONF_KEY_KEYS GCONF_KEY_PREFIX"/keys/"
+#define GCONF_KEY_KEY_DIR GCONF_KEY_PREFIX"/keys"
+#define GCONF_KEY_KEYS GCONF_KEY_KEY_DIR"/"
 
 #define HSPLIT 380
 #define VSPLIT 260
@@ -79,6 +80,7 @@ typedef struct _Application {
     GtkWidget *video_prev;
     GtkWidget *video_up;
     GtkWidget *video_down;
+    GtkWidget *aspects_toggle;
     GtkWidget * playlist_view;
     GtkWidget * downloads_view;
     GtkWidget * infopanel_view;
@@ -134,6 +136,7 @@ void cb_view_area_key_press (GtkWidget *widget, GdkEventKey *event, Application
 void cb_playlistMenuActivate (GtkWidget *w, GdkEvent *e, Application *app);
 void generatorMenuActivate (GtkMenuItem *item, Application * app);
 void playlistMenuActivate (GtkMenuItem *item, Application * app);
+void clearHistory (GtkMenuItem *item, Application * app);
 void cb_playlistCopy (GtkButton * button, Application * app);
 void cb_playlistPaste (GtkButton * button, Application * app);
 void cb_playlistPasteInNewGroup (GtkButton * button, Application * app);
@@ -145,6 +148,7 @@ void cb_playlist_next (GtkButton * button, void *ctr);
 void cb_playlist_stop (GtkButton * button, void *ctr);
 void cb_playlist_save (GtkButton * button, void *ctr);
 void cb_favorites_add (GtkButton *, Application *app);
+void cb_aspects_toggle (GtkButton *, void *ctr);
 gboolean playlist_selected (Application *app, GValue *icon, GValue *text);
 void collapseSelectedList (Application *app);
 void expandSelectedList (Application *app);
