@@ -74,12 +74,27 @@ Node *ATOM::Entry::childFromTag (const String &tag) {
 
 void ATOM::Entry::closed () {
     MediaGroup *group = NULL;
+    Link *link = NULL;
+
     for (Node *c = firstChild (); c; c = c->nextSibling ())
         if (c->id == id_node_title) {
             title = c->innerText ().stripWhiteSpace ();
+        } else if (c->id == id_node_link) {
+            Link *lnk = static_cast <Link *> (c);
+            if (!lnk->src.isEmpty ())
+                link = lnk;
         } else if (c->id == id_node_media_group) {
             group = static_cast <MediaGroup *> (c);
         }
+
+    if (link && group)
+        for (Node *c = group->firstChild (); c; c = c->nextSibling ())
+            if (id_node_media_content == c->id && c->mrl ()->src == link->src) {
+                link->src.clear ();
+                link->title.clear ();
+                break;
+            }
+
     Element::closed ();
 }
 
@@ -119,8 +134,8 @@ void ATOM::Link::closed () {
     }
     if (!href.isEmpty () && rel == "enclosure")
         src = href;
-    else if (title.isEmpty ())
-        title = href;
+    else if (src.isEmpty ())
+        title.clear ();
     Mrl::closed ();
 }
 
@@ -184,9 +199,20 @@ void ATOM::MediaGroup::closed () {
             }
 }
 
+static bool playedAnyChild (const Node *n) {
+    for (Node *c = n->firstChild (); c; c = c->nextSibling ()) {
+        Mrl *mrl = c->mrl ();
+        if (mrl && (mrl->has_played || playedAnyChild (c)))
+            return true;
+    }
+    return false;
+}
+
 void ATOM::MediaGroup::message (MessageType msg, void *content) {
     if (MsgChildFinished == msg &&
-            id_node_media_content == ((Posting *) content)->source->id)
+            id_node_media_content == ((Posting *) content)->source->id &&
+            (((Posting *) content)->source->mrl ()->has_played ||
+             playedAnyChild (((Posting *) content)->source.ptr ())))
         finish (); // only play one
     Element::message (msg, content);
 }
