@@ -576,7 +576,7 @@ void Control::playCurrent () {
             setCurrent (playlist_data->document);
         else { // ugly code duplicate w/ back_request
             for (Node *p = playlist_data->current->parentNode(); p; p = p->parentNode())
-                p->state = Element::state_activated;
+                p->setState (Element::state_activated);
         }
         playlist_data->current->activate ();
         updateViewAreaSizes ();
@@ -630,7 +630,7 @@ bool Control::applyBackRequest() {
     } else {
         setCurrent (back_request);
         for (Node *p = back_request->parentNode(); p; p = p->parentNode())
-            p->state = Element::state_activated;
+            p->setState (Element::state_activated);
         back_request = 0L;
         g_timeout_add(0, playCurrentSchedule, static_cast<void*>(this));
     }
@@ -824,13 +824,11 @@ void Control::stateElementChanged (Node* n, Node::State os, Node::State ns) {
             videoDetected ();
             updateViewAreaSizes (); // move away video widget
         }
-        if (n->isPlayable () &&
-                n->mrl ()->view_mode == Mrl::SingleMode) {
-            Node *p = n->parentNode();
-            if (!p || !p->mrl () || p->mrl ()->view_mode == Mrl::SingleMode)
+        if (SMIL::id_node_smil == n->id &&
+                (!playlist_data->current ||
+                 SMIL::id_node_smil != playlist_data->current->id))
                 // make sure we don't set current to nested document
-                setCurrent (n);
-        }
+            setCurrent (n);
     }
     if (n == playlist_data->current &&
             (ns == Node::state_activated || ns == Node::state_deactivated))
@@ -841,10 +839,6 @@ void Control::updateViewAreaSizes () {
     if (!m_process || !VIEWAREA(m_app)->videoXId ())
         return;
     VIEWAREA(m_app)->resizeEvent();
-    IRect video_rect = VIEWAREA(m_app)->videoGeometry ();
-    int x = video_rect.x ();
-    int y = video_rect.y ();
-    m_process->setVideoWindow (x, y, video_rect.width (), video_rect.height ());
 }
 
 void Control::updatePlaylistView (bool force) {
@@ -1195,6 +1189,13 @@ void cb_playlist_stop (GtkButton * button, void *p) {
     ctr->stop ();
 }
 
+void cb_aspects_toggle (GtkButton * button, void *p)
+{
+    Control *ctr = (Control *)p;
+    ctr->viewArea()->toggleUseAspects ();
+    ctr->updateViewAreaSizes ();
+}
+
 void cb_playlist_save (GtkButton * button, void *p) {
     Control *ctr = (Control *)p;
     if (ctr->current_selected) {
@@ -1446,7 +1447,7 @@ locationbarGainFocus (GtkWidget *, GdkEventFocus *, Application * app) {
     app_set_playing (app, app->playing);
     if (!locationbar_initialized) {
         const char * defs[6] = {
-            "http://www.cwi.nl/SMIL/EUROshow/EUROshowB.smi",
+            "http://gdata.youtube.com/feeds/api/videos?vq=MeeGo",
             "http://homepages.cwi.nl/~media/SMIL/fiets/fiets.smil",
             "http://www.theworld.org/rss/tech.xml",
             "http://www.etherbeat.com/shoutcast/64.pls",
@@ -1631,6 +1632,77 @@ void generatorMenuActivate (GtkMenuItem *item, Application *app) {
         ctrl->current_generator->activate ();
 }
 
+static void
+clearHistoryResponse (GtkDialog *dialog, gint response, gpointer data) {
+    *((bool *) data) = response == GTK_RESPONSE_ACCEPT;
+}
+
+#include <hildon/hildon-check-button.h>
+
+static GtkWidget *clearButton (GtkWidget *box, const char *title)
+{
+    GtkWidget *button = hildon_check_button_new ((HildonSizeType)
+            (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT));
+    gtk_button_set_label (GTK_BUTTON (button), title);
+    hildon_check_button_set_active (HILDON_CHECK_BUTTON (button), true);
+    gtk_box_pack_start (GTK_BOX (box), button, true, true, 1);
+    return button;
+}
+
+void clearHistory (GtkMenuItem *item, Application *app)
+{
+    GtkWidget *dialog = gtk_dialog_new_with_buttons ("Clear History",
+            app->window,
+            GtkDialogFlags(GTK_DIALOG_MODAL|GTK_DIALOG_DESTROY_WITH_PARENT),
+            GTK_STOCK_OK,
+            GTK_RESPONSE_ACCEPT,
+            NULL);
+    GtkWidget *content = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+    GtkWidget *recents = clearButton (content, "Clear Recent List");
+    GtkWidget *locations = clearButton (content, "Clear Location Bar");
+    GtkWidget *generators = clearButton (content, "Clear Generators Input");
+    gtk_widget_show_all (content);
+
+    bool clear = false;
+    g_signal_connect (G_OBJECT (dialog), "response",
+            G_CALLBACK (clearHistoryResponse), &clear);
+
+    gtk_dialog_run (GTK_DIALOG (dialog));
+
+    if (clear) {
+        Control *ctr = CONTROL(app);
+        KMPlayer::Config *config = ctr->m_config;
+        if (hildon_check_button_get_active (HILDON_CHECK_BUTTON (locations))) {
+            locationbar_initialized = false;
+            gtk_list_store_clear (GTK_LIST_STORE (gtk_combo_box_get_model (
+                            GTK_COMBO_BOX (app->location_bar))));
+            KMPlayer::String cfg_pfx (GCONF_KEY_LOCATION_URL);
+            for (int i = 1; i < 7; i++)
+                config->writeEntry (cfg_pfx + KMPlayer::String::number(i), "");
+            gtk_combo_box_set_active_iter (GTK_COMBO_BOX (app->location_bar), NULL);
+        }
+        if (hildon_check_button_get_active (HILDON_CHECK_BUTTON (generators))) {
+            GConfClient *gcnf = (GConfClient *) *config;
+            GSList *keys = gconf_client_all_entries (gcnf, GCONF_KEY_KEY_DIR, NULL);
+            for (GSList *elm = keys; elm; elm = elm->next) {
+                GConfEntry *entry = (GConfEntry *)elm->data;
+                gconf_client_unset (gcnf, entry->key, NULL);
+                gconf_entry_free (entry);
+            }
+            g_slist_free (keys);
+        }
+        if (hildon_check_button_get_active (HILDON_CHECK_BUTTON (recents))) {
+            if (ctr->recents) {
+                ctr->recents->defer ();
+                ctr->recents->clear ();
+            }
+            updateTree (app, app->recents_tree_id);
+            syncSchedule (ctr);
+        }
+    }
+    gtk_widget_destroy (dialog);
+}
+
 static void
 playlistResponse (GtkDialog *dialog, gint response, gpointer data) {
     if (response == GTK_RESPONSE_OK) {
