@@ -1018,7 +1018,7 @@ void cb_playlistTitle (Application *app) {
             if (!title.isNull ()) {
                 pr->setCaption (title);
                 static_cast <Element *> (node)->setAttribute (
-                        StringPool::attr_title, title);
+                        Ids::attr_title, title);
                 node->document ()->m_tree_version++;
                 updateTree (app, app->playlists_tree_id);
             }
